ClientBuilder

Struct ClientBuilder 

pub struct ClientBuilder { /* private fields */ }
Builds a Client with a chosen transaction timeout, retransmission schedule and handler.

Implementations

Source

impl ClientBuilder

pub fn with_rto(self, rto: Duration) -> Self

with_rto sets client RTO as defined in STUN RFC.

pub fn with_timeout_rate(self, d: Duration) -> Self

with_timeout_rate sets RTO timer minimum resolution.

pub fn with_buffer_size(self, buffer_size: usize) -> Self

with_buffer_size sets buffer size.

pub fn with_no_retransmit(self) -> Self

with_no_retransmit disables retransmissions and sets RTO to DEFAULT_MAX_ATTEMPTS * DEFAULT_RTO which will be effectively time out if not set. Useful for TCP connections where transport handles RTO.

pub fn new() -> Self

A builder with the RFC’s default timings.

pub fn build( self, local: SocketAddr, remote: SocketAddr, protocol: TransportProtocol, ) -> Result<Client>

Builds the client for the given local and remote addresses.

Errors

Fails if the configured timings are inconsistent.