Setter

Trait Setter 

pub trait Setter {
    // Required method
    fn add_to(&self, m: &mut Message) -> Result<()>;
}
Interfaces that are implemented by message attributes, shorthands for them, or helpers for message fields as type or transaction id.

Required Methods

fn add_to(&self, m: &mut Message) -> Result<()>

Encodes this value into m as an attribute.

Errors

Fails if the value cannot be encoded, or the message has no room for it.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors