pub trait Setter {
// Required method
fn add_to(&self, m: &mut Message) -> Result<()>;
}Expand description
Interfaces that are implemented by message attributes, shorthands for them, or helpers for message fields as type or transaction id.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".